@@ -1,10 +1,9 @@
-#### Lastest load into a package.
+### Lastest load into a package.
 
-### Export Namespace does not use .First.lib() and .Last.lib(), but use
-### .onLoad() and .onUnload().
-# .First.lib <- function(lib, pkg){
-# } # End of .First.lib().
+## Export Namespace does not use .First.lib() and .Last.lib(), but use
+## .onLoad() and .onUnload().
 
+#' @export
 .Last.lib <- function(libpath){
   ### To free all BLACS points.
   base.finalize(mpi.finalize = FALSE)
@@ -18,10 +17,6 @@
     }
   }
 
-  if(! is.loaded("slap_blacs_gridinit", PACKAGE = "pbdSLAP")){
-    library.dynam("pbdSLAP", "pbdSLAP", libname)
-  }
-
   library.dynam("pbdBASE", pkgname, libname)
   invisible()
 } # End of .onLoad().
