@@ -2,7 +2,7 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-// Copyright 2014, Schmidt
+// Copyright 2014, 2016 Schmidt
 
 #include "pbdBASE.h"
 
@@ -13,8 +13,9 @@ SEXP COMM_STOP(char *msg)
   SEXP Rmsg;
   SEXP ret;
   
-  PROTECT(mpiPackage);
-  mpiPackage = eval( lang2( install("getNamespace"), ScalarString(mkChar("pbdMPI")) ), R_GlobalEnv );
+  PROTECT(mpiPackage = 
+    eval( lang2( install("getNamespace"), ScalarString(mkChar("pbdMPI")) ), R_GlobalEnv )
+  );
   
   PROTECT(Rmsg = allocVector(STRSXP, 1));
   SET_STRING_ELT(Rmsg, 0, mkChar(msg));
@@ -33,8 +34,9 @@ SEXP COMM_WARNING(char *msg)
   SEXP Rmsg;
   SEXP ret;
   
-  PROTECT(mpiPackage);
-  mpiPackage = eval( lang2( install("getNamespace"), ScalarString(mkChar("pbdMPI")) ), R_GlobalEnv );
+  PROTECT(mpiPackage = 
+    eval( lang2( install("getNamespace"), ScalarString(mkChar("pbdMPI")) ), R_GlobalEnv )
+  );
   
   PROTECT(Rmsg = allocVector(STRSXP, 1));
   SET_STRING_ELT(Rmsg, 0, mkChar(msg));
@@ -50,15 +52,14 @@ SEXP COMM_WARNING(char *msg)
 SEXP COMM_PRINT(SEXP x)
 {
   SEXP mpiPackage;
-  SEXP Rmsg;
   SEXP ret;
   
-  PROTECT(mpiPackage);
-  mpiPackage = eval( lang2( install("getNamespace"), ScalarString(mkChar("pbdMPI")) ), R_GlobalEnv );
+  PROTECT(mpiPackage = 
+    eval( lang2( install("getNamespace"), ScalarString(mkChar("pbdMPI")) ), R_GlobalEnv )
+  );
   
   ret = eval( lang2( install("comm.print"), x ), mpiPackage );
   
   UNPROTECT(2);
   return ret;
 }
-
